@@ -1,16 +1,23 @@
+from django.conf import settings
+
+
 class AuthRouter:
     """
     A router to control all database operations on models in the
     auth and contenttypes applications.
     """
     route_app_labels = {'auth', 'contenttypes', 'admin', }
+    try:
+        auth_db = settings.AUTH_DB
+    except NameError:
+        auth_db = 'default'
 
     def db_for_read(self, model, **hints):
         """
         Attempts to read auth and contenttypes models go to auth_db.
         """
         if model._meta.app_label in self.route_app_labels:
-            return 'auth_db'
+            return self.auth_db
         return None
 
     def db_for_write(self, model, **hints):
@@ -18,7 +25,7 @@ class AuthRouter:
         Attempts to write auth and contenttypes models go to auth_db.
         """
         if model._meta.app_label in self.route_app_labels:
-            return 'auth_db'
+            return self.auth_db
         return None
 
     def allow_relation(self, obj1, obj2, **hints):
@@ -36,8 +43,8 @@ class AuthRouter:
     def allow_migrate(self, db, app_label, model_name=None, **hints):
         """
         Make sure the auth and contenttypes apps only appear in the
-        'auth_db' database.
+        auth_db database.
         """
         if app_label in self.route_app_labels:
-            return db == 'auth_db'
+            return db == self.auth_db
         return None
